@@ -154,7 +154,7 @@ def meter_block_convert_to_eth_block(block):
     
 
 conns = {}
-WSURL_NHEADS = 'ws://127.0.0.1:8669/subscriptions/beat'
+# WSURL_NHEADS = 'ws://127.0.0.1:8669/subscriptions/beat'
 
 def hash_digest(param):
     h = hashlib.sha224(param.encode())
@@ -210,7 +210,6 @@ async def websocket_handler(request):
 
                         # handle batch requests
                         if isinstance(jreq, list):
-                            print("HANDLE LIST")
                             ress = []
                             for r in jreq:
                                 res = await handleRequest(r, False, False)
@@ -253,7 +252,7 @@ async def websocket_handler(request):
                         else:
                             # handle normal requests
                             res = await handleRequest(json.loads(msg.data), False, False)
-                            print("Send to %s" % key)
+                            print("Forward response to ws conn %s" % key)
                             await ws.send_str(res)
                             # await ws.send_str(json.dumps({"jsonrpc":"2.0", "result":json.loads(res), "id":count}))
                         
